BufferUsage

Struct BufferUsage 

pub struct BufferUsage { /* private fields */ }
Different ways that you can use a buffer.

The usages determine what kind of memory the buffer is allocated from and what actions the buffer can partake in.

Implementations

Source

impl BufferUsage

pub const MAP_READ: BufferUsage

Allow a buffer to be mapped for reading using [Buffer::map_async] + [Buffer::get_mapped_range]. This does not include creating a buffer with BufferDescriptor::mapped_at_creation set.

If Features::MAPPABLE_PRIMARY_BUFFERS isn’t enabled, the only other usage a buffer may have is COPY_DST.

pub const MAP_WRITE: BufferUsage

Allow a buffer to be mapped for writing using [Buffer::map_async] + [Buffer::get_mapped_range_mut]. This does not include creating a buffer with mapped_at_creation set.

If Features::MAPPABLE_PRIMARY_BUFFERS feature isn’t enabled, the only other usage a buffer may have is COPY_SRC.

pub const COPY_SRC: BufferUsage

Allow a buffer to be the source buffer for a [CommandEncoder::copy_buffer_to_buffer] or [CommandEncoder::copy_buffer_to_texture] operation.

pub const COPY_DST: BufferUsage

Allow a buffer to be the source buffer for a [CommandEncoder::copy_buffer_to_buffer], [CommandEncoder::copy_buffer_to_texture], or [Queue::write_buffer] operation.

pub const INDEX: BufferUsage

Allow a buffer to be the index buffer in a draw operation.

pub const VERTEX: BufferUsage

Allow a buffer to be the vertex buffer in a draw operation.

pub const UNIFORM: BufferUsage

Allow a buffer to be a BindingType::UniformBuffer inside a bind group.

pub const STORAGE: BufferUsage

Allow a buffer to be a BindingType::StorageBuffer inside a bind group.

pub const INDIRECT: BufferUsage

Allow a buffer to be the indirect buffer in an indirect draw call.

pub const fn empty() -> BufferUsage

Returns an empty set of flags

pub const fn all() -> BufferUsage

Returns the set containing all flags.

pub const fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<BufferUsage>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> BufferUsage

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> BufferUsage

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: BufferUsage) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: BufferUsage) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: BufferUsage)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: BufferUsage)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: BufferUsage)

Toggles the specified flags in-place.

pub fn set(&mut self, other: BufferUsage, value: bool)

Inserts or removes the specified flags depending on the passed value.