pub struct RenderBundle { /* private fields */ }Expand description
Pre-prepared reusable bundle of GPU operations.
It only supports a handful of render commands, but it makes them reusable. RenderBundles
can be executed onto a CommandEncoder using RenderPass::execute_bundles.
Executing a RenderBundle is often more efficient then issuing the underlying commands manually.