pub struct SamplerDescriptorBase<L> {
pub label: L,
pub address_mode_u: AddressMode,
pub address_mode_v: AddressMode,
pub address_mode_w: AddressMode,
pub mag_filter: FilterMode,
pub min_filter: FilterMode,
pub mipmap_filter: FilterMode,
pub lod_min_clamp: f32,
pub lod_max_clamp: f32,
pub compare: Option<CompareFunction>,
pub anisotropy_clamp: Option<u8>,
pub _non_exhaustive: NonExhaustive,
}Expand description
Describes a [Sampler]
Fields
label: LDebug label of the sampler. This will show up in graphics debuggers for easy identification.
address_mode_u: AddressModeHow to deal with out of bounds accesses in the u (i.e. x) direction
address_mode_v: AddressModeHow to deal with out of bounds accesses in the v (i.e. y) direction
address_mode_w: AddressModeHow to deal with out of bounds accesses in the w (i.e. z) direction
mag_filter: FilterModeHow to filter the texture when it needs to be magnified (made larger)
min_filter: FilterModeHow to filter the texture when it needs to be minified (made smaller)
mipmap_filter: FilterModeHow to filter between mip map levels
lod_min_clamp: f32Minimum level of detail (i.e. mip level) to use
lod_max_clamp: f32Maximum level of detail (i.e. mip level) to use
compare: Option<CompareFunction>If this is enabled, this is a comparison sampler using the given comparison function.
anisotropy_clamp: Option<u8>Valid values: 1, 2, 4, 8, and 16.
_non_exhaustive: NonExhaustiveThis struct must be partially constructed from its default
Implementations
Sourceimpl<L> SamplerDescriptor<L>
impl<L> SamplerDescriptor<L>
pub fn map_label<K>(&self, fun: impl FnOnce(&L) -> K) -> SamplerDescriptor<K>